@@ -1,7 +1,7 @@
 from .. import testing
 
 
-class SumTest(testing.FunctionalTestCase):
+class SumIfsTest(testing.FunctionalTestCase):
     filename = "SUMIFS.xlsx"
 
     def test_evaluation_A10(self):
